import { useCallback, useEffect, useMemo, useRef, useState } from 'react';
import deepEqual from 'deep-equal';
import { getConfiguration, onConfigurationChanged } from '@codingame/monaco-editor-wrapper';
import { StandaloneServices, IThemeService } from 'vscode/services';
export function useColorTheme() {
    const themeService = useMemo(() => StandaloneServices.get(IThemeService), []);
    const [theme, setTheme] = useState(themeService.getColorTheme());
    useEffect(() => {
        const disposable = themeService.onDidColorThemeChange(() => {
            setTheme(themeService.getColorTheme());
        });
        // Since useEffect is asynchronous, the theme may have changed between the initialization of state and now
        // Let's update the state just in case
        setTheme(themeService.getColorTheme());
        return () => {
            disposable.dispose();
        };
    }, [themeService]);
    return theme;
}
export function useUserConfiguration(programmingLanguageId) {
    const [userConfiguration, setUserConfiguration] = useState(() => getConfiguration());
    useEffect(() => {
        const updateOptions = () => {
            setUserConfiguration(getConfiguration(programmingLanguageId));
        };
        const configurationChangeDisposable = onConfigurationChanged(updateOptions);
        return () => {
            configurationChangeDisposable.dispose();
        };
    }, [programmingLanguageId]);
    return userConfiguration;
}
export function useLastValueRef(value) {
    const ref = useRef(value);
    ref.current = value;
    return ref;
}
export function useLastVersion(func) {
    const ref = useRef(func);
    useEffect(() => {
        ref.current = func;
    }, [func]);
    return useCallback((...args) => {
        return ref.current(...args);
        // eslint-disable-next-line react-hooks/exhaustive-deps
    }, []);
}
export function usePrevious(value) {
    const ref = useRef();
    useEffect(() => {
        ref.current = value;
    }, [value]);
    return ref.current;
}
export function useDeepMemo(memoFn, deps, isEqual = deepEqual) {
    const ref = useRef();
    if (ref.current == null || !isEqual(deps, ref.current.deps)) {
        ref.current = { deps, value: memoFn() };
    }
    return ref.current.value;
}
//# sourceMappingURL=hooks.js.map